@@ -39,9 +39,6 @@ import sys
 import platform
 
 
-# See https://setuptools.readthedocs.io/en/latest/deprecated/\
-#                                      distutils-legacy.html
-os.environ['SETUPTOOLS_USE_DISTUTILS'] = 'local'
 from setuptools import setup, Extension
 import distutils.ccompiler
 
@@ -500,7 +497,7 @@ you can use legacy `bsddb3 <https://pypi.org/project/bsddb3/>`__ library.
       author = 'Jesús Cea Avión, Robin Dunn, Gregory P. Smith, Andrew Kuchling, Barry Warsaw',
       author_email = 'pybsddb@jcea.es',
       url = 'https://www.jcea.es/programacion/pybsddb.htm',
-      license = "3-clause BSD License",
+      license = "BSD-3-Clause",
 
       packages = ['berkeleydb'],
       package_dir = {'berkeleydb': 'src/berkeleydb'},
@@ -508,7 +505,6 @@ you can use legacy `bsddb3 <https://pypi.org/project/bsddb3/>`__ library.
       headers = ['src/Module/berkeleydb.h'],
       data_files = utils,
       classifiers = [
-                    'License :: OSI Approved :: BSD License',
                     'Development Status :: 5 - Production/Stable',
                     'Intended Audience :: Developers',
                     'Intended Audience :: Information Technology',
@@ -522,11 +518,11 @@ you can use legacy `bsddb3 <https://pypi.org/project/bsddb3/>`__ library.
                     'Topic :: Software Development',
                     'Topic :: System :: Clustering',
                     'Programming Language :: Python :: 3',
-                    'Programming Language :: Python :: 3.9',
                     'Programming Language :: Python :: 3.10',
                     'Programming Language :: Python :: 3.11',
                     'Programming Language :: Python :: 3.12',
                     'Programming Language :: Python :: 3.13',
+                    'Programming Language :: Python :: 3.14',
                     ],
       )
 
