@@ -456,8 +456,12 @@ def process_args(argv=None):
         # If we called "setup()" directly, we could specify
         # the parameter "extra_compile_args".
         if 'CFLAGS' not in os.environ:
-            os.environ['CFLAGS'] = '-Wall -Werror -Wextra ' \
-                      '-Wno-error=cast-function-type -Wno-cast-function-type'
+            #
+            # Beware, we have some ugly workarounds in the code to be
+            # able to compile it with GCC in pedantic mode.
+            #
+            os.environ['CFLAGS'] = '-Wpedantic -Wall -Werror -Wextra ' \
+                      '-Wno-cast-function-type'
 
         cmd = sys.executable + ' setup.py build'
         sts = os.system(cmd)
