@@ -41,9 +41,11 @@ import unittest
 import time
 import sys
 import pathlib
+from test.support.os_helper import rmtree
+
 
 from berkeleydb import db
-from .test_all import rmtree, get_new_environment_path, \
+from .test_all import get_new_environment_path, \
         get_new_database_path, printable_bytes
 
 DASH = b'-'
