@@ -33,10 +33,10 @@
 
 import unittest
 import pathlib
+from test.support.os_helper import rmtree, unlink
 
 from berkeleydb import db
-from .test_all import rmtree, unlink, get_new_environment_path, \
-        get_new_database_path
+from .test_all import get_new_environment_path, get_new_database_path
 
 #----------------------------------------------------------------------
 
