@@ -34,9 +34,10 @@
 import unittest
 import os
 import pathlib
+from test.support.os_helper import rmtree
 
 from berkeleydb import db
-from .test_all import rmtree, get_new_environment_path
+from .test_all import get_new_environment_path
 
 #----------------------------------------------------------------------
 
