@@ -37,10 +37,11 @@
 import shutil
 import pathlib
 import unittest
+from test.support.os_helper import rmtree, unlink
 
 from berkeleydb import db
-from .test_all import rmtree, unlink, \
-                      get_new_environment_path, get_new_database_path
+from .test_all import get_new_environment_path, get_new_database_path
+
 
 class FileidResetTestCase(unittest.TestCase):
     def setUp(self):
