@@ -37,10 +37,12 @@ TestCases for checking set_get_returns_none.
 
 import os
 import unittest
+from test.support.os_helper import rmtree
+
 
 
 from berkeleydb import db
-from .test_all import rmtree, get_new_environment_path, \
+from .test_all import get_new_environment_path, \
         get_new_database_path, printable_bytes
 
 
