@@ -37,9 +37,10 @@ TestCases for testing the locking sub-system.
 
 import time
 import unittest
+from test.support.os_helper import rmtree
 
 from berkeleydb import db
-from .test_all import rmtree, get_new_environment_path
+from .test_all import get_new_environment_path
 
 from threading import Thread
 
