@@ -35,10 +35,10 @@
 """
 
 import unittest
+from test.support.os_helper import rmtree, unlink
 
 from berkeleydb import db, hashopen, dbshelve
-from .test_all import rmtree, unlink, \
-        get_new_environment_path, get_new_database_path
+from .test_all import get_new_environment_path, get_new_database_path
 
 #----------------------------------------------------------------------
 
