@@ -36,9 +36,10 @@
 
 import os
 import unittest
+from test.support.os_helper import rmtree, unlink
 
 from berkeleydb import db
-from .test_all import rmtree, unlink, printable_bytes, \
+from .test_all import printable_bytes, \
         get_new_environment_path, get_new_database_path
 
 
