@@ -40,9 +40,11 @@ import time
 import queue
 import unittest
 from test.support.socket_helper import find_unused_port
+from test.support.os_helper import rmtree
+
 
 from berkeleydb import db
-from .test_all import rmtree, get_new_environment_path
+from .test_all import get_new_environment_path
 
 #----------------------------------------------------------------------
 
